@@ -1,4 +1,5 @@
 from itsimodels.core.base_models import BaseModel, ChildModel
+from itsimodels.core.compat import string_types
 from itsimodels.core.fields import (
     BoolField,
     DictField,
@@ -17,19 +18,30 @@ KPI_SUMMARY_RE = r'`get_full_itsi_summary_kpi\((.+)\)`'
 KV_STORE_KEY_RE = r'splunk-enterprise-kvstore://(.+)'
 
 
+class ValuedModel(ChildModel):
+
+    def to_dict(self, *args, **kwargs):
+        obj = super(ValuedModel, self).to_dict(*args, **kwargs)
+
+        # Remove any null values to conform with the UI visualization library
+        data = {key: value for key, value in obj.items() if value}
+
+        return data
+
+
 class DataSourceMeta(ChildModel):
     kpi_id = ForeignKey('itsimodels.service.Kpi', alias='kpiID')
 
     service_id = ForeignKey('itsimodels.service.Service', alias='serviceID')
 
 
-class DataSourceOptions(ChildModel):
+class DataSourceOptions(ValuedModel):
     data = DictField()
 
     query = ForeignKey('itsimodels.service.Kpi', key_regex=KPI_SUMMARY_RE)
 
 
-class DataSource(ChildModel):
+class DataSource(ValuedModel):
     meta = TypeField(DataSourceMeta)
 
     name = StringField()
@@ -76,7 +88,7 @@ class StructureItem(ChildModel):
 
 
 class Layout(ChildModel):
-    global_inputs = ListField(str, alias='globalInputs')
+    global_inputs = ListField(string_types, alias='globalInputs')
 
     options = TypeField(LayoutOptions)
 
@@ -85,11 +97,17 @@ class Layout(ChildModel):
     type = StringField()
 
 
-class VisualizationOptions(ChildModel):
+class VisualizationOptions(ValuedModel):
     background_color = StringField(alias='backgroundColor')
 
+    color = StringField()
+
+    content = StringField()
+
     fill = StringField()
 
+    font_size = NumberField(alias='fontSize')
+
     icon = ForeignKey('itsimodels.glass_table_icon.GlassTableIcon', key_regex=KV_STORE_KEY_RE)
 
     number_precision = NumberField(alias='numberPrecision')
@@ -109,7 +127,7 @@ class VisualizationOptions(ChildModel):
     stroke_width = NumberField(alias='strokeWidth')
 
 
-class Visualization(ChildModel):
+class Visualization(ValuedModel):
     data_sources = DictField(alias='dataSources')
 
     options = TypeField(VisualizationOptions)
@@ -138,6 +156,8 @@ class GlassTable(BaseModel):
 
     description = StringField(default='')
 
+    gt_version = StringField(default='beta')
+
     latest = StringField(default='now')
 
     latest_label = StringField(default='Now')
