@@ -11,18 +11,28 @@ from itsimodels.core.fields import (
     TypeField
 )
 from itsimodels.team import GLOBAL_TEAM_KEY
+from itsimodels.core.setup_logging import logger
 
 
 class ThresholdLevel(ChildModel):
+
+    dynamic_param = NumberField(alias='dynamicParam')
+
     severity_color = StringField(alias='severityColor')
 
     severity_color_light = StringField(alias='severityColorLight')
 
     severity_label = StringField(alias='severityLabel')
 
+    severity_label_localized = StringField(alias='severityLabelLocalized')
+
+    severity_value = NumberField(alias='severityValue')
+
     threshold_value = NumberField(alias='thresholdValue')
 
 
+
+
 class KpiThresholds(ChildModel):
     base_severity_color = StringField(alias='baseSeverityColor')
 
@@ -66,9 +76,28 @@ class KpiTimePolicies(ChildModel):
 
 
 class MetricSearchSpec(ChildModel):
-     metric_index = StringField(default='')
+    metric_index = StringField(default='')
 
-     metric_name = StringField(default='')
+    metric_name = StringField(default='')
+
+
+class DatamodelFilter(ChildModel):
+
+    field = StringField(alias='_field')
+
+    operator = StringField(alias='_operator')
+
+    value = StringField(alias='_value')
+
+
+class DatamodelSearchSpec(ChildModel):
+    datamodel = StringField()
+
+    object = StringField()
+
+    field = StringField()
+
+    owner_field = StringField()
 
 
 class Kpi(ChildModel):
@@ -76,12 +105,22 @@ class Kpi(ChildModel):
 
     title = StringField(required=True)
 
+    alert_eval = StringField()
+
+    aggregate_eval = StringField()
+
     aggregate_statop = StringField(default='avg')
 
+    adaptive_thresholding_training_window = StringField()
+
     adaptive_thresholds_is_enabled = BoolField(default=False)
 
     aggregate_thresholds = TypeField(KpiThresholds)
 
+    aggregate_thresholds_alert_enabled = BoolField(default=False)
+
+    aggregate_thresholds_custom_alert_enabled = BoolField(default=False)
+
     aggregate_thresholds_custom_alert_rules = ListField()
 
     alert_lag = StringField(default='30')
@@ -114,6 +153,12 @@ class Kpi(ChildModel):
 
     cohesive_anomaly_detection_is_enabled = BoolField(default=False)
 
+    datamodel = TypeField(DatamodelSearchSpec)
+
+    datamodel_filter = ListField(DatamodelFilter)
+
+    datamodel_filter_clauses = StringField()
+
     description = StringField(default='')
 
     enabled = BoolField(default=False)
@@ -138,6 +183,8 @@ class Kpi(ChildModel):
 
     gap_severity_value = StringField(default='-1')
 
+    kpi_base_search = StringField()
+
     kpi_template_kpi_id = ForeignKey('itsimodels.kpi_threshold_template.KpiThresholdTemplate')
 
     kpi_threshold_template_id = StringField()
@@ -152,6 +199,8 @@ class Kpi(ChildModel):
 
     search = StringField()
 
+    search_aggregate = StringField()
+
     search_alert = StringField()
 
     search_alert_earliest = StringField()
@@ -160,10 +209,24 @@ class Kpi(ChildModel):
 
     search_buckets = StringField()
 
+    search_entities = StringField()
+
     search_occurrences = NumberField()
 
+    search_time_compare = StringField()
+
+    search_time_series = StringField()
+
+    search_time_series_entities = StringField()
+
+    search_time_series_aggregate = StringField()
+
     search_type = StringField(default='adhoc')
 
+    service_title = StringField()
+
+    threshold_eval = StringField()
+
     threshold_field = StringField(default='')
 
     time_policies = TypeField(KpiTimePolicies, alias='time_variate_thresholds_specification')
@@ -226,6 +289,8 @@ class Service(BaseModel):
 
     services_depending_on_me = ListField(ServiceDependency)
 
+    service_id = ForeignKey('itsimodels.service.Service')
+
     service_template_id = ForeignKey('itsimodels.service_template.ServiceTemplate', alias='base_service_template_id')
 
     service_tags = TypeField(ServiceTags)
